<div align="center">

# ayaka文字小游戏合集 - 0.0.0b0

开发进度 9/10，还剩1个小游戏等待构思

**特别感谢**  [@灯夜](https://github.com/lunexnocty/Meiri) 大佬的插件蛮好玩的~

</div>

## 安装

```
pip install ayaka_games
```

## 指令

猫猫帮助

## 踩坑

CRLF换行符的文件，会在github上被强制换为LF换行符再发放，这会导致文件哈希值变化
